ProSHADE: Class Members - Functions

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

### - g -

- getAllAngleDifferences() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- getAllCSyms() : ProSHADE_run
- getAllGroupElements() : ProSHADE_internal_data::ProSHADE_data
- getAllPossibleFolds() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- getAngularDim() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- getAnySphereRadius() : ProSHADE_internal_data::ProSHADE_data
- getBestIndexForFold() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- getBestRotationMapPeaksEulerAngles() : ProSHADE_internal_data::ProSHADE_data
- getBestTranslationMapPeaksAngstrom() : ProSHADE_internal_data::ProSHADE_data
- getCommandLineParams() : ProSHADE_settings
- getComparisonBand() : ProSHADE_internal_data::ProSHADE_data
- getCyclicSymmetriesList() : ProSHADE_internal_data::ProSHADE_data
- getCyclicSymmetriesListFromAngleAxis() : ProSHADE_internal_data::ProSHADE_data
- getDihedralSymmetriesList() : ProSHADE_internal_data::ProSHADE_data
- getEMatrixByBand() : ProSHADE_internal_data::ProSHADE_data
- getEMatrixValue() : ProSHADE_internal_data::ProSHADE_data
- getEnergyLevelsVector() : ProSHADE_run
- getEulerAngles() : ProSHADE_run
- getIcosahedralSymmetriesList() : ProSHADE_internal_data::ProSHADE_data
- getImagEMatrixValuesForLM() : ProSHADE_internal_data::ProSHADE_data
- getImagRotFunction() : ProSHADE_internal_data::ProSHADE_data
- getImagSO3Coeffs() : ProSHADE_internal_data::ProSHADE_data
- getImagSphHarmValue() : ProSHADE_internal_data::ProSHADE_data
- getImagTranslationFunction() : ProSHADE_internal_data::ProSHADE_data
- getIntegrationWeight() : ProSHADE_internal_data::ProSHADE_data
- getInternalMap() : ProSHADE_internal_data::ProSHADE_data
- getInterpolationXYZ() : ProSHADE_internal_spheres::ProSHADE_sphere
- getInvSO3Coeffs() : ProSHADE_internal_data::ProSHADE_data
- getLatFromIndices() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- getLattitudeCutoffs() : ProSHADE_internal_spheres::ProSHADE_sphere
- getLatToIndices() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- getLocalAngRes() : ProSHADE_internal_spheres::ProSHADE_sphere
- getLocalBandwidth() : ProSHADE_internal_spheres::ProSHADE_sphere
- getLonFromIndices() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- getLongitudeCutoffs() : ProSHADE_internal_spheres::ProSHADE_sphere
- getLonToIndices() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- getMappedData() : ProSHADE_internal_spheres::ProSHADE_sphere
- getMapPoint() : ProSHADE_internal_spheres::ProSHADE_sphere
- getMapValue() : ProSHADE_internal_data::ProSHADE_data , ProSHADE_run
- getMaxBand() : ProSHADE_internal_data::ProSHADE_data
- getMaxCircumference() : ProSHADE_internal_spheres::ProSHADE_sphere
- getMaxRadius() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- getMaxSpheres() : ProSHADE_internal_data::ProSHADE_data
- getMinRadius() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- getNoRecommendedSymmetryAxes() : ProSHADE_internal_data::ProSHADE_data , ProSHADE_run
- getNoStructures() : ProSHADE_run
- getNoSymmetryAxes() : ProSHADE_run
- getOctahedralSymmetriesList() : ProSHADE_internal_data::ProSHADE_data
- getOptimalRotMat() : ProSHADE_run
- getOriginalBounds() : ProSHADE_run
- getOriginToOverlayTranslation() : ProSHADE_run
- getOverlayRotationFunction() : ProSHADE_internal_data::ProSHADE_data
- getPeaks() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- getPredictedIcosahedralSymmetriesList() : ProSHADE_internal_data::ProSHADE_data
- getPredictedOctahedralSymmetriesList() : ProSHADE_internal_data::ProSHADE_data
- getRadius() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- getRealEMatrixValuesForLM() : ProSHADE_internal_data::ProSHADE_data
- getRealRotFunction() : ProSHADE_internal_data::ProSHADE_data
- getRealSO3Coeffs() : ProSHADE_internal_data::ProSHADE_data
- getRealSphHarmValue() : ProSHADE_internal_data::ProSHADE_data
- getRealTranslationFunction() : ProSHADE_internal_data::ProSHADE_data
- getReBoxBoundaries() : ProSHADE_internal_data::ProSHADE_data
- getReBoxedBounds() : ProSHADE_run
- getRecommendedSymmetryFold() : ProSHADE_internal_data::ProSHADE_data
- getRecommendedSymmetryType() : ProSHADE_internal_data::ProSHADE_data
- getRepresentedAngle() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- getRotatedMappedData() : ProSHADE_internal_spheres::ProSHADE_sphere
- getRotationFunctionVector() : ProSHADE_run
- getRotMatrixFromRotFunInds() : ProSHADE_internal_data::ProSHADE_data
- getRRPValue() : ProSHADE_internal_data::ProSHADE_data
- getShellBandwidth() : ProSHADE_internal_data::ProSHADE_data
- getShellRadius() : ProSHADE_internal_spheres::ProSHADE_sphere
- getSO3Coeffs() : ProSHADE_internal_data::ProSHADE_data
- getSphereLatLonLinearInterpolationPos() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- getSphereLatLonPosition() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- getSphereNumber() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- getSpherePositions() : ProSHADE_internal_data::ProSHADE_data , ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- getSpherePosValue() : ProSHADE_internal_data::ProSHADE_data
- getSpheresFormingFold() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- getSymmetryAxis() : ProSHADE_internal_data::ProSHADE_data , ProSHADE_run
- getSymmetryFold() : ProSHADE_run
- getSymmetryType() : ProSHADE_run
- getTetrahedralSymmetriesList() : ProSHADE_internal_data::ProSHADE_data
- getTraceSigmaVector() : ProSHADE_run
- getTranslationFnPointer() : ProSHADE_internal_data::ProSHADE_data
- getTranslationToOrigin() : ProSHADE_run
- getValue() : ProSHADE_internal_maths::BicubicInterpolator
- getVerbose() : ProSHADE_run
- getWignerMatrixValue() : ProSHADE_internal_data::ProSHADE_data
- getXAxisOrigin() : ProSHADE_internal_data::ProSHADE_data
- getXDim() : ProSHADE_internal_data::ProSHADE_data
- getXDimSize() : ProSHADE_internal_data::ProSHADE_data
- getXFromPtr() : ProSHADE_internal_data::ProSHADE_data
- getXToPtr() : ProSHADE_internal_data::ProSHADE_data
- getXYZTopBottoms() : ProSHADE_internal_spheres::ProSHADE_sphere
- getYAxisOrigin() : ProSHADE_internal_data::ProSHADE_data
- getYDim() : ProSHADE_internal_data::ProSHADE_data
- getYDimSize() : ProSHADE_internal_data::ProSHADE_data
- getYFromPtr() : ProSHADE_internal_data::ProSHADE_data
- getYToPtr() : ProSHADE_internal_data::ProSHADE_data
- getZAxisOrigin() : ProSHADE_internal_data::ProSHADE_data
- getZDim() : ProSHADE_internal_data::ProSHADE_data
- getZDimSize() : ProSHADE_internal_data::ProSHADE_data
- getZFromPtr() : ProSHADE_internal_data::ProSHADE_data
- getZToPtr() : ProSHADE_internal_data::ProSHADE_data